@@ -30,7 +30,7 @@ import multiprocessing
 def createRandomSegs( numSegs, minVal=0, maxVal=10000 ):
         '''
         Create a bunch of random line segments within a bounding box.  Segments may or may not intersect,
-        but colinear and overlapping segments are not allowed..
+        but collinear and overlapping segments are not allowed..
         Duplicates will be removed.  
 
         **input**:
@@ -45,11 +45,10 @@ def createRandomSegs( numSegs, minVal=0, maxVal=10000 ):
         RL = []
         for i in range( 0, numSegs ):
                 s = ((random.randint(minVal, maxVal), random.randint(minVal, maxVal)), (random.randint(minVal, maxVal), random.randint(minVal, maxVal))  )
-                cmpVal = poiComp( s[0],s[1] )
-                if cmpVal == -1:
-                        RL.append( s )
-                elif cmpVal == 1:
-                        RL.append( (s[1],s[0]) )
+                if s[0] < s[1]:
+                  RL.append( s )
+                elif s[1] < s[0]: 
+                  RL.append( (s[1],s[0]) )
 
         # remove dups
         rlSet = set()
@@ -93,11 +92,10 @@ def calcNonIntersectingSegsIntEndPoints( segs ):
         newSegs =[]
 
         for s in segs:
-                cmpVal = poiComp( s[0],s[1] )
-                if cmpVal == -1:
-                        newSegs.append( s )
-                elif cmpVal == 1:
-                        newSegs.append( (s[1],s[0]) )
+                if s[0] < s[1]:
+                  newSegs.append( s )
+                elif s[1] < s[0]:
+                  newSegs.append( (s[1],s[0]) )
         # remove any intersecting segs
 
         segs = newSegs
@@ -150,7 +148,7 @@ def calcNonIntersectingSegsIntEndPoints( segs ):
 
 def collinear( L, R, tolerance = 0.0000001 ):
         '''
-        Test if two line segments are colinear within a tolerance.
+        Test if two line segments are collinear within a tolerance.
 
         **input**: 
 
@@ -158,14 +156,14 @@ def collinear( L, R, tolerance = 0.0000001 ):
 
         R: a line segment like L
 
-        tolerance:   a tolerance value.  Set to 0 for exact colinearity test, higher for greater tolerance.
+        tolerance:   a tolerance value.  Set to 0 for exact collinearity test, higher for greater tolerance.
         
         **output**:
 
         boolean value
         '''
         if tolerance != 0:
-                # will be colinear if l1,l2,r1 and l1,l2,r2 are all within collinear tolerance
+                # will be collinear if l1,l2,r1 and l1,l2,r2 are all within collinear tolerance
                 # uses left turn test.
                 p1x = L[0][0]
                 p1y = L[0][1]
@@ -197,7 +195,7 @@ def collinear( L, R, tolerance = 0.0000001 ):
 
 def isCollinearAndOverlapping( L,R, tolerance = .0000001 ):
         '''
-        test if two segments are both colinear AND overlapping.  Colinearity within a tolerance is allowed.
+        test if two segments are both collinear AND overlapping.  Collinearity within a tolerance is allowed.
 
         **input**:
 
@@ -205,16 +203,20 @@ def isCollinearAndOverlapping( L,R, tolerance = .0000001 ):
 
         R: line segment with structure as L
 
-        tolerance: set to 0 for exact colinearity test.  Otherwise, allows *almost* colinear to count as colinear
+        tolerance: set to 0 for exact collinearity test.  Otherwise, allows *almost* collinear to count as collinear
 
         **returns**:
 
-        *True* if L and R are colinear within tolerance and overlapping
+        *True* if L and R are collinear within tolerance and overlapping
 
         *False* otherwise
         '''
+        if L == None or R == None:
+                return False
+
         if L == R or L == (R[1], R[0]):
                 return True
+
         if collinear( L, R, tolerance ):
                 if L[0][0] == L[1][0] or R[0][0] == R[1][0]: #vertical segs:
                         vals = [ (L[0][1],'l') , (L[1][1],'l'), (R[0][1],'r'), (R[1][1],'r') ]
@@ -265,7 +267,7 @@ def calcIntersectionPointsRedBlue( segs1, segs2, indexList1 = None, indexList2 =
         if indexList2 == None:
                 indexList2 = range( len( segs2 ) )
         lfloat = float
-        lisColinearAndOverlapping = isColinearAndOverlapping
+        lisCollinearAndOverlapping = isCollinearAndOverlapping
         for i in range( len( segs1 ) ):
                 for j in range( len( segs2 ) ):
                         x1 = lfloat( segs1[i][0][0] )
@@ -291,7 +293,7 @@ def calcIntersectionPointsRedBlue( segs1, segs2, indexList1 = None, indexList2 =
                                 continue
 
                         denom = ((y4-y3)*(x2-x1)) - ((x4-x3)*(y2-y1))
-                        if lisColinearAndOverlapping( segs1[i], segs2[j] ):
+                        if lisCollinearAndOverlapping( segs1[i], segs2[j] ):
                                 ll = segs1[i][0][0]
                                 lu = segs1[i][1][0]
                                 rl = segs2[j][0][0]
@@ -440,7 +442,7 @@ def isLeftTurn( p1,p2,p3):
 
         -1 if a left turn is needed
 
-        0 if the points are colinear
+        0 if the points are collinear
 
         1 if a right turn is needed
         '''
@@ -939,7 +941,7 @@ def calcIntersectionPoints( segs, laList = None, lbList = None, indexList = None
                                 continue
                                         
                         denom = ((y4-y3)*(x2-x1)) - ((x4-x3)*(y2-y1))
-                        if isColinearAndOverlapping( segs[i], segs[j] ):
+                        if isCollinearAndOverlapping( segs[i], segs[j] ):
                                 ll = segs[i][0][0]
                                 lu = segs[i][1][0]
                                 rl = segs[j][0][0]
@@ -1003,56 +1005,9 @@ def calcIntersectionPoints( segs, laList = None, lbList = None, indexList = None
         return pois
 
 
-def isColinearAndOverlapping( Lseg, Rseg, tolerance = .0000001 ):
+def collinearValue( p1,p2,p3):
         '''
-        This is a duplicate of isCollinearAndOverlapping()  (notice the mispelling).
-
-        The functions are implemented differently, but seem to do the same thing.
-
-        NEEDS TO BE ADDRESSED.
-
-        I think the other function is implemented better, but this one is spelled correctly.
-
-        '''
-        L = (Lseg[0], Lseg[1])
-        R = (Rseg[0], Rseg[1])
-        
-        if L == None or R == None:
-                return False
-        if L == R or L == (R[1], R[0]):
-                return True
-        negt = tolerance * -1
-        # will be colinear if l1,l2,r1 and l1,l2,r2 are all within tolerance
-        v1 = colinearValue( L[0], L[1], R[0])
-        v2 = colinearValue( L[0], L[1], R[1])
-
-        if negt <= v1 and v1 <= tolerance and negt <= v2 and v2 <= tolerance:
-                # lines are colinear. values to compare
-                ll = L[0][0]
-                lu = L[1][0]
-                rl = R[0][0]
-                ru = R[1][0]
-                if ll == lu: #vertical lines
-                        ll = L[0][1]
-                        lu = L[1][1]
-                        rl = R[0][1]
-                        ru = R[1][1]
-                if lu < ll:
-                        tmp = ll
-                        ll = lu
-                        lu = tmp
-                if ru < rl:
-                        tmp = rl
-                        rl = ru
-                        ru = tmp
-                # if one value from R is between the values from L, they are colinear and overlapping
-                # eqivalent segs are checked way at the top
-                if ((ll < rl and rl < lu) or ( ll < ru and ru < lu)) or  ((rl < ll and ll < ru) or ( rl < lu and lu < ru)):
-                        return True
-        return False
-def colinearValue( p1,p2,p3):
-        '''
-        uses the left hand turn test based on the sign of the area of the trianngle defiened by points p1,p2, and p3, except that the actual value is returned.  This is useful if you want to see how close the three points are to being colinear.  
+        uses the left hand turn test based on the sign of the area of the trianngle defiened by points p1,p2, and p3, except that the actual value is returned.  This is useful if you want to see how close the three points are to being collinear.  
         
         Left hand turn test assumes you are traveling from p1 to p2 and then on to p3, and indicates if you must make a left or right turn at p2 to reach p3.
 
@@ -1060,7 +1015,7 @@ def colinearValue( p1,p2,p3):
 
         **output**: the signed area of the square enclosing the triangle defined by the given points.
        
-        * will return a 0 if p1, p2,p3 are exactly colinear
+        * will return a 0 if p1, p2,p3 are exactly collinear
         
         * will return positive value if it forms a left turn
         
@@ -1193,25 +1148,6 @@ def constructSegsWithLabels( pois, segs, laList, lbList ):
         return [list(u) for u in zip(*retList)]
 
 
-def poiComp( p1, p2 ):
-        '''
-        compare two points. 
-
-        **input**: two points, p1 and p2, with format (x,y)
-
-        **output**:
-
-        -1 if p1 < p2
-
-        0 if p1 == p2
-
-        1 if p1 > p2
-        '''
-        if p1 == p2:
-                return 0
-        if p1[0] < p2[0] or (p1[0] == p2[0] and p1[1] < p2[1] ):
-                return -1
-        return 1
 def snapEndPoints( segs ):
         ''' 
         Does 2 things:
@@ -1332,7 +1268,7 @@ def checkNumRobustnes( segs ):
                 allPoints.append( s[0][1] )
         # sort the points
 #       print 'sortnow'
-        allPoints = sorted( allPoints, cmp=poiComp )
+        allPoints = sorted( allPoints )
 #       print 'ALLPOINTS', len( allPoints )
 
         #remove duplicates
